@@ -178,11 +178,14 @@ def cli(
 @click.option('--skip-lock', is_flag=True, default=False, help=u"Ignore locking mechanisms when installing—use the Pipfile, instead.")
 @click.option('--deploy', is_flag=True, default=False, help=u"Abort if the Pipfile.lock is out–of–date, or Python version is wrong.")
 @click.option('--pre', is_flag=True, default=False, help=u"Allow pre–releases.")
+@click.option('--keep-outdated', is_flag=True, default=False, help=u"Keep out–dated dependencies from being updated in Pipfile.lock.")
+@click.option('--selective-upgrade', is_flag=True, default=False, help="Update specified packages.")
 def install(
     package_name=False, more_packages=False, dev=False, three=False,
     python=False, system=False, lock=True, ignore_pipfile=False,
     skip_lock=False, verbose=False, requirements=False, sequential=False,
-    pre=False, code=False, deploy=False
+    pre=False, code=False, deploy=False, keep_outdated=False,
+    selective_upgrade=False
 ):
     from . import core
     core.do_install(
@@ -190,7 +193,8 @@ def install(
         three=three, python=python, system=system, lock=lock,
         ignore_pipfile=ignore_pipfile, skip_lock=skip_lock, verbose=verbose,
         requirements=requirements, sequential=sequential, pre=pre, code=code,
-        deploy=deploy
+        deploy=deploy, keep_outdated=keep_outdated,
+        selective_upgrade=selective_upgrade
     )
 
 
@@ -204,15 +208,17 @@ def install(
 @click.option('--lock', is_flag=True, default=True, help="Lock afterwards.")
 @click.option('--all-dev', is_flag=True, default=False, help="Un-install all package from [dev-packages].")
 @click.option('--all', is_flag=True, default=False, help="Purge all package(s) from virtualenv. Does not edit Pipfile.")
+@click.option('--keep-outdated', is_flag=True, default=False, help=u"Keep out–dated dependencies from being updated in Pipfile.lock.")
 def uninstall(
     package_name=False, more_packages=False, three=None, python=False,
-    system=False, lock=False, all_dev=False, all=False, verbose=False
+    system=False, lock=False, all_dev=False, all=False, verbose=False,
+    keep_outdated=False
 ):
     from . import core
     core.do_uninstall(
         package_name=package_name, more_packages=more_packages, three=three,
         python=python, system=system, lock=lock, all_dev=all_dev, all=all,
-        verbose=verbose
+        verbose=verbose, keep_outdated=keep_outdated
     )
 
 
@@ -225,7 +231,8 @@ def uninstall(
 @click.option('--dev', '-d', is_flag=True, default=False, help="Generate output compatible with requirements.txt for the development dependencies.")
 @click.option('--clear', is_flag=True, default=False, help="Clear the dependency cache.")
 @click.option('--pre', is_flag=True, default=False, help=u"Allow pre–releases.")
-def lock(three=None, python=False, verbose=False, requirements=False, dev=False, clear=False, pre=False):
+@click.option('--keep-outdated', is_flag=True, default=False, help=u"Keep out–dated dependencies from being updated in Pipfile.lock.")
+def lock(three=None, python=False, verbose=False, requirements=False, dev=False, clear=False, pre=False, keep_outdated=False):
     from . import core
     # Ensure that virtualenv is available.
     core.ensure_project(three=three, python=python)
@@ -237,7 +244,7 @@ def lock(three=None, python=False, verbose=False, requirements=False, dev=False,
     if requirements:
         core.do_init(dev=dev, requirements=requirements)
 
-    core.do_lock(verbose=verbose, clear=clear, pre=pre)
+    core.do_lock(verbose=verbose, clear=clear, pre=pre, keep_outdated=keep_outdated)
 
 
 
@@ -308,6 +315,67 @@ def check(three=None, python=False, system=False, unused=False, style=False, arg
     core.do_check(three=three, python=python, system=system, unused=unused, args=args)
 
 
+@click.command(short_help="Runs lock, then sync.")
+@click.option('--three/--two', is_flag=True, default=None, help="Use Python 3/2 when creating virtualenv.")
+@click.option('--python', default=False, nargs=1, help="Specify which version of Python virtualenv should use.")
+@click.option('--verbose', '-v', is_flag=True, default=False, help="Verbose mode.", callback=setup_verbose)
+@click.option('--dev', '-d', is_flag=True, default=False, help="Install package(s) in [dev-packages].")
+@click.option('--clear', is_flag=True, default=False, help="Clear the dependency cache.")
+@click.option('--bare', is_flag=True, default=False, help="Minimal output.")
+@click.option('--pre', is_flag=True, default=False, help=u"Allow pre–releases.")
+@click.option('--keep-outdated', is_flag=True, default=False, help=u"Keep out–dated dependencies from being updated in Pipfile.lock.")
+@click.option('--sequential', is_flag=True, default=False, help="Install dependencies one-at-a-time, instead of concurrently.")
+@click.option('--outdated', is_flag=True, default=False, help=u"List out–of–date dependencies.")
+@click.option('--dry-run', is_flag=True, default=None, help=u"List out–of–date dependencies.")
+@click.argument('packages', nargs=-1)
+@click.pass_context
+def update(ctx, three=None, python=False, system=False, verbose=False, clear=False, keep_outdated=False, pre=False, dev=False, bare=False, sequential=False, packages=None, dry_run=None, outdated=False):
+    from . import core
+
+    core.ensure_project(three=three, python=python, warn=True)
+
+    if not outdated:
+        outdated = bool(dry_run)
+
+    if outdated:
+        core.do_outdated()
+
+    if not packages:
+        click.echo('{0} {1} {2} {3}{4}'.format(
+            crayons.white('Running', bold=True),
+            crayons.red('$ pipenv lock', bold=True),
+            crayons.white('then', bold=True),
+            crayons.red('$ pipenv sync', bold=True),
+            crayons.white('.', bold=True),
+        ))
+
+        # Load the --pre settings from the Pipfile.
+        if not pre:
+            pre = core.project.settings.get('pre')
+
+        core.do_lock(verbose=verbose, clear=clear, pre=pre, keep_outdated=keep_outdated)
+        core.do_sync(
+            ctx=ctx, install=install, dev=dev, three=three, python=python,
+            bare=bare, dont_upgrade=False, user=False, verbose=verbose,
+            clear=clear, unused=False, sequential=sequential
+        )
+    else:
+
+        core.ensure_lockfile(keep_outdated=core.project.lockfile_exists)
+
+        for package in packages:
+            core.do_install(
+                package_name=package, dev=dev,
+                three=three, python=python, system=system, lock=True,
+                ignore_pipfile=False, skip_lock=False, verbose=verbose,
+                requirements=False, sequential=sequential, pre=pre, code=False,
+                deploy=False, keep_outdated=True,
+                selective_upgrade=True
+            )
+
+
+
+
 @click.command(short_help=u"Displays currently–installed dependency graph information.")
 @click.option('--bare', is_flag=True, default=False, help="Minimal output.")
 @click.option('--json', is_flag=True, default=False, help="Output JSON.")
@@ -392,6 +460,7 @@ cli.add_command(check)
 cli.add_command(clean)
 cli.add_command(shell)
 cli.add_command(run)
+cli.add_command(update)
 cli.add_command(run_open)
 
 
