@@ -23,6 +23,8 @@ from .environments import (
     PIPENV_PIPFILE,
     PIPENV_VENV_IN_PROJECT,
     PIPENV_VIRTUALENV,
+    PIPENV_NO_INHERIT,
+    PIPENV_TEST_INDEX
 )
 
 if PIPENV_PIPFILE:
@@ -35,7 +37,7 @@ if PIPENV_PIPFILE:
 class Project(object):
     """docstring for Project"""
 
-    def __init__(self, chdir=True):
+    def __init__(self, which=None, chdir=True):
         super(Project, self).__init__()
         self._name = None
         self._virtualenv_location = None
@@ -44,6 +46,7 @@ class Project(object):
         self._pipfile_location = None
         self._requirements_location = None
         self._original_dir = os.path.abspath(os.curdir)
+        self.which = which
 
         # Hack to skip this during pipenv run, or -r.
         if ('run' not in sys.argv) and chdir:
@@ -408,17 +411,20 @@ class Project(object):
         install = dict(config_parser.get_config_section('install'))
         indexes = install.get('extra-index-url', '').lstrip('\n').split('\n')
 
-        # Default source.
-        pypi_source = {u'url': u'https://pypi.python.org/simple', u'verify_ssl': True, u'name': 'pypi'}
-        sources = [pypi_source]
+        if PIPENV_TEST_INDEX:
+            sources = [{u'url': PIPENV_TEST_INDEX, u'verify_ssl': True, u'name': u'custom'}]
+        else:
+            # Default source.
+            pypi_source = {u'url': u'https://pypi.python.org/simple', u'verify_ssl': True, u'name': 'pypi'}
+            sources = [pypi_source]
 
-        for i, index in enumerate(indexes):
-            if not index:
-                continue
-            source_name = 'pip_index_{}'.format(i)
-            verify_ssl = index.startswith('https')
+            for i, index in enumerate(indexes):
+                if not index:
+                    continue
+                source_name = 'pip_index_{}'.format(i)
+                verify_ssl = index.startswith('https')
 
-            sources.append({u'url': index, u'verify_ssl': verify_ssl, u'name': source_name})
+                sources.append({u'url': index, u'verify_ssl': verify_ssl, u'name': source_name})
 
         data = {
             u'source': sources,
@@ -430,8 +436,7 @@ class Project(object):
         }
 
         # Default requires.
-        if python:
-            data[u'requires'] = {'python_version': python_version(python)[:len('2.7')]}
+        data[u'requires'] = {'python_version': python_version(self.which('python'))[:len('2.7')]}
 
         self.write_toml(data, 'Pipfile')
 
